<?php

namespace Quivers\Components;

require_once("Library/stripe-php/init.php"); // Stripe SDK Import
// use Stripe\Stripe;
use Quivers\Components\SettingService;
use Quivers\Components\Logtracking;

class QuiversStripe
{
   
    private $session;
    private $settingsService;

    public function __construct(SettingService $settingsService, Logtracking $logTracking)
    {
        $this->session = Shopware()->Session();
        $this->settingsService = $settingsService;
        $this->logTracking = $logTracking;
    }

    public function createPaymentResponse($user, $data)
    {
        $startTime = microtime(true);
        $payment_token = $this->session["payment_token"];
     
        $secret_key = $this->settingsService->get('secret_key', 'stripe_settings');

        $this->minAmount = $this->settingsService->get('min_order_total', 'stripe_settings');
        
        $orderVariables = $this->session['sOrderVariables'];
        
        \Stripe\Stripe::setApiKey($secret_key);
        
        $customerEmail = $user['additional']['user']['email'];


        // error_log("customer email is ".json_encode($customerEmail));
        try {
            // check if user with same email already exists in Stripe account.
            $customer = false;
            $customersList = \Stripe\Customer::all(array(
                "limit" => 1,
                "email" => $customerEmail,
            ));

            // create a new user if it doesn't exists.
            if(count($customersList["data"])>0) {
                $customer = $customersList["data"][0];
            }
            // error_log("customer (in customer list )is ".json_encode($customer));
   
            if(!$customer){
                $customer = \Stripe\Customer::create(array(
                'source' => $payment_token,
                'email' => $customerEmail,
                ));
                error_log("NEW Stripe customer is ".json_encode($customer));

            }

            $customerId = $customer["id"];
            // error_log("customer id is ".json_encode($customerId));
             try {
                    $customer->sources->create(array("source" => $payment_token));
                }
            catch (Exception $e) {}


        }
        catch (\Exception $e) {
        }
        $charge = $this->createCharge($customer, $data);
        $order_data = ["Customer Id"=>$customerId, "Email"=>$customerEmail];
        $response = ["Response"=>$charge["result"], "Amount"=>$data["amount"]];
        $this->logTracking->payment_request($order_data, "stripe", date('r', $startTime), $response, $charge["result"]["status"]);
        return $charge;

    }

    private function createCharge($customer, $data) 
    {
        $payment_token = $this->session["payment_token"];
        $amount = $data["amount"];
        $currency = $data["currency"];
        $stripeCustomerId= $customer['id'];
       
        $chargeAmount = $this->formatCurrencyAmount($amount, $currency);
        $orderVariables = $this->session['sOrderVariables'];
        $email = $orderVariables["sUserData"]["additional"]["user"]["email"];

        $redirectData = [
                'controller' => 'checkout',
                'action' => 'shippingPayment',
                'error_code' => 1,
        ];

        $statement_descriptor = $orderVariables["payment_descriptor"];
        if(strlen($statement_descriptor) > 10){
            $statement_descriptor = substr($statement_descriptor, 0, 10);
        }
        try {
            $request = array(
                'customer' => $customer->id,
                'source' => $payment_token,
                'capture' => false,
                'amount' => $chargeAmount,
                'currency' => $currency,
                'description' => sprintf('%s', $email),
                'statement_descriptor_suffix' => $statement_descriptor != null ? $statement_descriptor : 'QuiversInc'
            );
            if($orderVariables['destination'] === true){
                $merchantId = $orderVariables['merchantId'];
                if($merchantId != '0'){
                    $transferData = array(
                        "destination" => $merchantId,
                        "amount" => $chargeAmount
                    );
                    $onBehalfOf = $merchantId;
                    $request['transfer_data'] = $transferData;
                    $request['on_behalf_of'] = $onBehalfOf;
                }
            }
            // error_log("request is ".json_encode($request));
            
            $charge = \stripe\charge::create($request);
            // error_log("charge is ".json_encode($charge));
            return ['error_code' => 0,
                    'result' => $charge
            ];
        } 
        catch (\Stripe\Error\ApiConnection $e) {
            // Network problem, perhaps try again.
            $redirectData['error_name'] = "Network problem";
            $redirectData['error_message']  = 'Unable to connect to payment gateway server. Please try again. If the issue persists please contact Quivers at 805-250-4555';
            return ['error_code' => 1,
                    'result' => $redirectData
                ];

        } catch (\Stripe\Error\InvalidRequest $e) {
            // You screwed up in your programming. Shouldn't happen!
            $redirectData['error_name'] = "Invalid Request";
            $redirectData['error_message']  = 'Please try again. If the issue persists please contact Quivers at 805-250-4555';
            return ['error_code' => 1,
                    'result' => $redirectData
                ];

        } catch (\Stripe\Error\Api $e) {
            // Stripe's servers are down!
            $redirectData['error_name'] = "Connection Error";
            $redirectData['error_message']  = 'Unable to connect to payment gateway server. Please try again. If the issue persists please contact Quivers at 805-250-4555';
            return ['error_code' => 1,
                    'result' => $redirectData
                ];

        } catch (\Stripe\Error\Card $e) {
            // Card error.
            $redirectData['error_name'] = "Card error";
            $redirectData['error_message']  = 'Please verify the details before trying again. If the issue persists please contact Quivers at 805-250-4555';
            return ['error_code' => 1,
                    'result' => $redirectData
                ];
        }catch(\Exception $e) {
            //Exception
            $redirectData['error_name'] = "Error";
            $redirectData['error_message']  = $e->getMessage().'Please verify the details before trying again. If the issue persists please contact Quivers at 805-250-4555';
            return ['error_code' => 1,
                    'result' => $redirectData
            ];
        }

    }

     public function formatCurrencyAmount($amount, $currency)
    {

        // Stripe takes amounts as the smallest currency unit. ...

        if (empty($amount)) {
            return null;
        }
        $multiple = 100;
        if (in_array(
            $currency,
            array('BIF', 'DJF', 'JPY', 'KRW', 'PYG', 'VND', 'XAF', 'XPF', 'CLP', 'GNF', 'KMF', 'MGA', 'RWF', 'VUV', 'XOF'),
            true
        )) {
            $multiple = 1;
        }

        return sprintf('%01.0f', (float)$amount * $multiple);
    }

    

}