<?php

namespace Quivers\Subscriber;

use Enlight\Event\SubscriberInterface;
use Enlight_Controller_ActionEventArgs as ActionEventArgs;
use Quivers\Components\Position;
use Shopware\Bundle\AttributeBundle\Service\DataPersister;
use Shopware\Components\Model\ModelManager;


class Backend implements SubscriberInterface
{

    public function __construct(Position $position, DataPersister $dataPersistor, ModelManager $modelManager)
    {
        $this->position = $position;
        $this->dataPersistor = $dataPersistor;
        $this->modelManager = $modelManager;
        $this->dbalConnection = $modelManager->getConnection();

    }

     public static function getSubscribedEvents()
    {
        return [
          'Enlight_Controller_Action_PostDispatchSecure_Backend_AttributeData' => 'attributeUpdate',
          'Enlight_Controller_Action_PostDispatchSecure_Backend_Order' => 'positionUpdate',
        ];
    }

    public static function attributeUpdate(ActionEventArgs $args){
        $controller = $args->getSubject();
        $request = $controller->Request();
        $allowedActions = ['saveData'];
        $action = $controller->Request()->getActionName();
        $view = $controller->View();
        if (!in_array($action, $allowedActions, true)) {
            return;
        }
        
        if ($request->getParam('_table') == 's_articles_attributes'){
            $foreignKey =$request->getParam("_foreignKey");

            $articleId = $this->dbalConnection->createQueryBuilder()
                    ->select('articleID')
                    ->from('s_articles_details')
                    ->where('id = :id')
                    ->setParameter('id', $foreignKey)
                    ->execute()->fetchColumn();

            $allDetailId = $this->dbalConnection->createQueryBuilder()
                    ->select('id')
                    ->from('s_articles_details')
                    ->where('articleID = :articleID')
                    ->setParameter('articleID', $articleId)
                    ->execute()->fetchAll();

            $taxCode =$request->getParam("__attribute_product_tax_code");

            $data = ["product_tax_code" => $taxCode];

            foreach ($allDetailId as $value) {
                 $this->dataPersistor->persist(
                    $data,
                    $request->getParam('_table'),
                    $value['id']
                );
            }
        }
        $this->position->changedDateUpdate($args);
        $this->position->updateItem($args);
    }

     public static function positionUpdate(ActionEventArgs $args){
        $controller = $args->getSubject();
        $request = $controller->Request();
        $allowedActions = ['savePosition', 'save'];
        $action = $controller->Request()->getActionName();
        $view = $controller->View();
        if (!in_array($action, $allowedActions, true)) {
            return;
        }
        if (($action == 'savePosition') or ($action == 'save')){
              $this->position->changedDateUpdate($args);
        }
        if ($action == 'save'){
            $this->position->positionStatusUpdate($args);
        }
    }
}
